@@ -1,7 +1,7 @@
 import json
 import typing
 
-import xpresso.binders.dependants as dependants
+import xpresso.binders.dependents as dependents
 import xpresso.openapi.models as openapi_models
 from xpresso._utils.typing import Annotated, Literal
 from xpresso.binders._binders import file_body, form_body, json_body, union
@@ -17,7 +17,7 @@ def Json(
     enforce_media_type: bool = True,
     consume: bool = True,
     include_in_schema: bool = True,
-) -> dependants.BinderMarker:
+) -> dependents.BinderMarker:
     body_extractor_marker = json_body.ExtractorMarker(
         decoder=decoder,
         enforce_media_type=enforce_media_type,
@@ -28,13 +28,13 @@ def Json(
         examples=examples,
         include_in_schema=include_in_schema,
     )
-    return dependants.BinderMarker(
+    return dependents.BinderMarker(
         extractor_marker=body_extractor_marker,
         openapi_marker=body_openapi_marker,
     )
 
 
-def File(
+def RawBody(
     *,
     media_type: typing.Optional[str] = None,
     enforce_media_type: bool = True,
@@ -43,7 +43,7 @@ def File(
     format: Literal["binary", "base64"] = "binary",
     consume: bool = True,
     include_in_schema: bool = True,
-) -> dependants.BinderMarker:
+) -> dependents.BinderMarker:
     extractor_marker = file_body.ExtractorMarker(
         media_type=media_type,
         enforce_media_type=enforce_media_type,
@@ -56,7 +56,7 @@ def File(
         format=format,
         include_in_schema=include_in_schema,
     )
-    return dependants.BinderMarker(
+    return dependents.BinderMarker(
         extractor_marker=extractor_marker,
         openapi_marker=openapi_marker,
     )
@@ -109,7 +109,7 @@ def Form(
     examples: typing.Optional[typing.Dict[str, Example]] = None,
     description: typing.Optional[str] = None,
     include_in_schema: bool = True,
-) -> dependants.BinderMarker:
+) -> dependents.BinderMarker:
     extractor_marker = form_body.ExtractorMarker(
         media_type="application/x-www-form-urlencoded",
     )
@@ -119,7 +119,7 @@ def Form(
         media_type="application/x-www-form-urlencoded",
         include_in_schema=include_in_schema,
     )
-    return dependants.BinderMarker(
+    return dependents.BinderMarker(
         extractor_marker=extractor_marker,
         openapi_marker=openapi_marker,
     )
@@ -130,7 +130,7 @@ def Multipart(
     examples: typing.Optional[typing.Dict[str, Example]] = None,
     description: typing.Optional[str] = None,
     include_in_schema: bool = True,
-) -> dependants.BinderMarker:
+) -> dependents.BinderMarker:
     extractor_marker = form_body.ExtractorMarker(media_type="multipart/form-data")
     openapi_marker = form_body.OpenAPIMarker(
         description=description,
@@ -138,7 +138,7 @@ def Multipart(
         media_type="multipart/form-data",
         include_in_schema=include_in_schema,
     )
-    return dependants.BinderMarker(
+    return dependents.BinderMarker(
         extractor_marker=extractor_marker,
         openapi_marker=openapi_marker,
     )
@@ -147,23 +147,45 @@ def Multipart(
 def BodyUnion(
     *,
     description: typing.Optional[str] = None,
-) -> dependants.BinderMarker:
+) -> dependents.BinderMarker:
     extractor_marker = union.ExtractorMarker()
     openapi_marker = union.BodyOpenAPIMarker(
         description=description,
     )
-    return dependants.BinderMarker(
+    return dependents.BinderMarker(
         extractor_marker=extractor_marker,
         openapi_marker=openapi_marker,
     )
 
 
+if typing.TYPE_CHECKING:
+    from pydantic import BaseModel
+
+    from xpresso import UploadFile
+
+
 # Convenience type aliases
 _T = typing.TypeVar("_T")
-FromJson = Annotated[_T, Json()]
-FromFile = Annotated[_T, File()]
+_BaseModelT = typing.TypeVar("_BaseModelT", bound=typing.Union["BaseModel", None])
+FromJson = Annotated[_BaseModelT, Json()]
+_BinaryT = typing.TypeVar(
+    "_BinaryT",
+    bound=typing.Union[
+        bytes,
+        "UploadFile",
+        typing.AsyncIterator[bytes],
+        None,
+    ],
+)
+FromRawBody = Annotated[_BinaryT, RawBody()]
 FromFormField = Annotated[_T, FormField()]
-FromFormFile = Annotated[_T, FormFile()]
-FromFormData = Annotated[_T, Form()]
-FromMultipart = Annotated[_T, Multipart()]
+_FormFileT = typing.TypeVar(
+    "_FormFileT",
+    bound=typing.Union[
+        bytes, "UploadFile", typing.List[bytes], "typing.List[UploadFile]", None
+    ],
+)
+FromFormFile = Annotated[_FormFileT, FormFile()]
+FromFormData = Annotated[_BaseModelT, Form()]
+FromMultipart = Annotated[_BaseModelT, Multipart()]
 FromBodyUnion = Annotated[_T, BodyUnion()]
